/*****************************************************************************
* Copyright (c) Future Technology Devices International 2014
* propriety of Future Technology devices International.
*
* Software License Agreement
*
* This code is provided as an example only and is not guaranteed by FTDI. 
* FTDI accept no responsibility for any issues resulting from its use. 
* The developer of the final application incorporating any parts of this 
* sample project is responsible for ensuring its safe and correct operation 
* and for any consequences resulting from its use.
*****************************************************************************/
/**
* @file                           FT_VI800A_RELAY.h
* @brief                          Contains FT transport layer specific to SPI for arduino platform.
								  Tested platform version: Arduino 1.0.5
								  Dependencies: arduino standard SPI library
* @version                        0.1.0
* @date                           2014/06/04
*
*/

/* This application demonstrates the usage of library for RELAY module */

/* Arduino standard includes */
#include "SPI.h"
#include "Wire.h"

/* Platform specific includes */
#include "FT_VI800A_RELAY.h"
FT_VI800A_RELAY RELAY;

// Arduino SPI pins
const char Daughter1_SS   = 7;
const char FT800_CS = 9;
const char SD_CS = 8;
const char _3state_IO = 5;

int ploadPin        = 1;  // Connects to SH/!LD Parallel load pin the 165
int clockEnablePin  = 9;  // Connects to Clock Enable pin the 165
int clockPin        = 2; // Connects to the Clock pin the 165

void setup()
{
	RELAY.SetCSpin(SS); //set CS pin 
	RELAY.SetDaughter1SSpin(Daughter1_SS); //set Daughter1_SS pin
	
	/* Initialize SPI pins*/
	pinMode(SD_CS,OUTPUT);
	pinMode(FT800_CS,OUTPUT);
	digitalWrite(SD_CS,HIGH);
	digitalWrite(FT800_CS,HIGH);
	
	//IN ports pins
	pinMode(ploadPin, OUTPUT); //pin 1
	pinMode(clockEnablePin, INPUT); //pin 9
	pinMode(clockPin, OUTPUT); //pin 2
	pinMode(_3state_IO,OUTPUT);   // bus buffer 3-state
	pinMode(A0,OUTPUT);
  
	digitalWrite(A0,HIGH);
	digitalWrite(ploadPin, LOW);
	digitalWrite(ploadPin, HIGH);
	digitalWrite(_3state_IO,LOW);
	
	/* Initialize serial print related functionality */
	Serial.begin(9600);
    Serial.println("\n\r\n\r-----------Sample Application for RELAY--------------");
	
	RELAY.Init();  //Initialize SPI
	RELAY.WriteByte(0x00); //set OUT port LEDs off
}

char OutPortValues[] = {0x01,0x02,0x04,0x08};  //values to toggle out port LED's
int16_t OutPortCount=0; uint8_t val =0;
void loop()
{
  RELAY.WriteByte(OutPortValues[OutPortCount]);
  val = RELAY.ReadByte(OutPortValues[OutPortCount]);
  Serial.print("OUT-IN value :");
  Serial.println(val,HEX);
  delay(400);
  OutPortCount++;
  if(OutPortCount >= 4)
  {
    OutPortCount=0;
  }
}