/*****************************************************************************
* Copyright (c) Future Technology Devices International 2014
* propriety of Future Technology devices International.
*
* Software License Agreement
*
* This code is provided as an example only and is not guaranteed by FTDI. 
* FTDI accept no responsibility for any issues resulting from its use. 
* The developer of the final application incorporating any parts of this 
* sample project is responsible for ensuring its safe and correct operation 
* and for any consequences resulting from its use.
*****************************************************************************/
/**
* @file                           FT_VI800A_RELAY.h
* @brief                          Contains FT transport layer specific to SPI for arduino platform.
								  Tested platform version: Arduino 1.0.5
								  Dependencies: arduino standard SPI library
* @version                        0.1.0
* @date                           2014/06/04
*
*/

#ifndef FT_VI800A_RELAY_H
#define FT_VI800A_RELAY_H

#include "SPI.h"

/* class definition of transport layer for TTLU/232U/N485U addon board */
/* Apis mainly can be classified into, init/begin, read, write, exit etc */
class FT_VI800A_RELAY
{

	public:
	
	/* API to write byte */
	void WriteByte( char data) 
	{
	  digitalWrite(Daughter1_SSpin,LOW);  //set chip select to low
	  SPI.transfer(data);   //trasnfer data
	  digitalWrite(Daughter1_SSpin,HIGH);  //set chip select to high
	}
	
	/* API to read byte */
	char ReadByte(char data) 
	{
	  delay(1);
	  digitalWrite(A0,LOW);  // load 
	  delay(1);
	  digitalWrite(A0,HIGH);  //shift
	  delay(1);
	  
	  digitalWrite(Daughter1_SSpin,LOW);  //set chip select to low
	  char rdata = SPI.transfer(data);
	  digitalWrite(Daughter1_SSpin,HIGH);  //set chip select to high
	  return rdata;  
	}
	
	/*Api to set the cs pin number */
	void SetCSpin(uint8_t cspin)
	{
		CSPin = cspin;
	}
	
	/* API to set Daughter1_SS pin*/
	void SetDaughter1SSpin(uint8_t daughter1_ss)
	{
		Daughter1_SSpin = daughter1_ss;
	}
	
	/* API to initialize the library */
	void Init()
	{
		pinMode(CSPin,OUTPUT);
		pinMode(Daughter1_SSpin,OUTPUT);
		digitalWrite(CSPin,HIGH);
		digitalWrite(Daughter1_SSpin,HIGH);
			
		SPI.begin();
		SPI.setClockDivider(SPI_CLOCK_DIV2);
		SPI.setBitOrder(MSBFIRST);
		SPI.setDataMode(SPI_MODE1); 		
	}
	
	/* API to close the spi channel */
	void Exit()
	{
		SPI.end();
	}
uint8_t CSPin;
uint8_t Daughter1_SSpin;
};
#endif /* FT_VI800A_RELAY_H */
